@@ -51,15 +51,29 @@ LAMBDA_REMOTE_DOCKER = os.environ.get('LAMBDA_REMOTE_DOCKER', '').lower().strip(
 # network that the docker lambda container will be joining
 LAMBDA_DOCKER_NETWORK = os.environ.get('LAMBDA_DOCKER_NETWORK', '').strip()
 
+# directory for persisting data
+DATA_DIR = os.environ.get('DATA_DIR', '').strip()
+
 # folder for temporary files and data
 TMP_FOLDER = os.path.join(tempfile.gettempdir(), 'localstack')
 
+# create folders
+for folder in [DATA_DIR, TMP_FOLDER]:
+    if folder and not os.path.exists(folder):
+        try:
+            os.makedirs(folder)
+        except Exception:
+            # this can happen due to a race condition when starting
+            # multiple processes in parallel. Should be safe to ignore
+            pass
+
+# fix for Mac OS, to be able to mount /var/folders in Docker
+if TMP_FOLDER.startswith('/var/folders/') and os.path.exists('/private%s' % TMP_FOLDER):
+    TMP_FOLDER = '/private%s' % TMP_FOLDER
+
 # temporary folder of the host (required when running in Docker). Fall back to local tmp folder if not set
 HOST_TMP_FOLDER = os.environ.get('HOST_TMP_FOLDER', TMP_FOLDER)
 
-# directory for persisting data
-DATA_DIR = os.environ.get('DATA_DIR', '').strip()
-
 # whether to use SSL encryption for the services
 USE_SSL = os.environ.get('USE_SSL', '').strip() in TRUE_STRINGS
 
@@ -171,7 +185,7 @@ try:
     if not is_in_docker:
         DOCKER_HOST_FROM_CONTAINER = socket.gethostbyname('host.docker.internal')
     # update LOCALSTACK_HOSTNAME if host.docker.internal is available
-    if is_in_docker and LOCALSTACK_HOSTNAME == DOCKER_BRIDGE_IP:
+    if is_in_docker and not os.environ.get('LOCALSTACK_HOSTNAME'):
         LOCALSTACK_HOSTNAME = DOCKER_HOST_FROM_CONTAINER
 except socket.error:
     pass
@@ -189,20 +203,6 @@ if not is_in_docker and 'docker' in LAMBDA_EXECUTOR and not is_linux():
 # local config file path in home directory
 CONFIG_FILE_PATH = os.path.join(expanduser('~'), '.localstack')
 
-# create folders
-for folder in [DATA_DIR, TMP_FOLDER]:
-    if folder and not os.path.exists(folder):
-        try:
-            os.makedirs(folder)
-        except Exception:
-            # this can happen due to a race condition when starting
-            # multiple processes in parallel. Should be safe to ignore
-            pass
-
-# fix for Mac OS, to be able to mount /var/folders in Docker
-if TMP_FOLDER.startswith('/var/folders/') and os.path.exists('/private%s' % TMP_FOLDER):
-    TMP_FOLDER = '/private%s' % TMP_FOLDER
-
 # set variables no_proxy, i.e., run internal service calls directly
 no_proxy = ','.join(set((LOCALSTACK_HOSTNAME, HOSTNAME, LOCALHOST, '127.0.0.1', '[::1]')))
 if os.environ.get('no_proxy'):
